<template>
  <BasicModal width="700px" :height=300 v-bind="$attrs" @register="register" :title="t('添加锡膏胶水记录')" @ok="handleSubmit">
    <div style="width: 600px;height: 300px;" class="pt-24px pr-12px">
      <BasicForm @register="registerForm" :model="model" />
    </div>
  </BasicModal>
</template>
<script lang="ts">
import { defineComponent, ref, nextTick, unref } from 'vue';
import { BasicModal, useModalInner } from '/@/components/Modal';
import { BasicForm, FormSchema, useForm } from '/@/components/Form/index';
import { SaveSolder,optionsListApi } from '/@/api/tigerapi/mes/smt/solder';
import { useI18n } from '/@/hooks/web/useI18n';
import { useMessage } from '/@/hooks/web/useMessage';
import{ useLocale } from '/@/locales/useLocale';

const { getLocale }=useLocale();

const { t } = useI18n('');
const { createMessage } = useMessage();
const schemas: FormSchema[] = [
  {
    field: 'UPN',
    component: 'Input',
    label: 'UPN',
    defaultValue: '',
    colProps: {
      span: 12,
    },
    required: true,
  },
  {
    field: 'CPN',
    component: 'Input',
    label: 'CPN编码',
    defaultValue: '',
    colProps: {
      span: 12,
    },
    required: true,
  },
  {
    field: 'TYPE',
    label: '类型',
    component: 'ApiSelect',
    colProps: { span: 12 },
    componentProps: {
      api: optionsListApi,
      resultField: 'Data',
      labelField: unref(getLocale)=='zh_CN'?'Desc':'Name',
      valueField: 'Value',
    },
  },
  {
    field: 'EXP_DATE',
    component: 'DatePicker',
    label: '有效期',
    colProps: {
      span: 12,
    },
    required: true,
  },
];
export default defineComponent({
  components: { BasicModal, BasicForm },
  props: {
    userData: { type: Object },
  },
  emit: ['success', 'register'],
  setup(_, { emit }) {
    const modelRef = ref({});
    const [
      registerForm,
      {
        // setFieldsValue,
        // setProps
        validate,
      },
    ] = useForm({
      labelWidth: 120,
      schemas,
      showActionButtonGroup: false,
      actionColOptions: {
        span: 24,
      },
    });

    const [register, { setModalProps, closeModal }] = useModalInner((data) => {
      setModalProps({ confirmLoading: false });
      data && onDataReceive(data);
    });

    function onDataReceive(data) {
      console.log('Data Received', data);
      // 方式1;
      // setFieldsValue({
      //   field2: data.data,
      //   field1: data.info,
      // });

      // // 方式2
      modelRef.value = { field2: data.data, field1: data.info, SHELF_CODE: '', SHELF_NAME: '' };

      // setProps({
      //   model:{ field2: data.data, field1: data.info }
      // })
    }

    // function handleVisibleChange(v) {
    //   v && props.userData && nextTick(() => onDataReceive(props.userData));
    // }

    async function handleSubmit() {
      try {
        const values = await validate();
        setModalProps({ confirmLoading: true });
        // TODO custom api
        //添加锡膏胶水记录
        const apiAction = SaveSolder(values, unref(false));
        apiAction.then((action) => {
          if (action) {
            if (action.IsSuccessed) {
                closeModal();
                createMessage.success(t('添加成功'));
                emit('success', {
                  isUpdate: unref(false),
                  values: { ...values, id: 0 },
                });
            }
          } else {
            createMessage.error(t('添加失败,代码已使用'));
          }
        });
      } finally {
        setModalProps({ confirmLoading: false });
      }
    }

    return { register, schemas, registerForm, model: modelRef, handleSubmit, t };
  },
});
</script>
